package edu.iris.dmc.ws.examples;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.TimeZone;

import edu.iris.dmc.criteria.CriteriaException;
import edu.iris.dmc.criteria.EventCriteria;
import edu.iris.dmc.event.model.Event;
import edu.iris.dmc.event.model.Magnitude;
import edu.iris.dmc.event.model.Origin;
import edu.iris.dmc.service.EventService;
import edu.iris.dmc.service.NoDataFoundException;
import edu.iris.dmc.service.ServiceNotSupportedException;
import edu.iris.dmc.service.ServiceUtil;


public class EventExample {

   public static void main(String[] args) {

      ServiceUtil serviceManager;
      try {
         //initialize the service
         serviceManager = ServiceUtil.getInstance();

         serviceManager.setAppName("Examples");
         EventService eventService = serviceManager.getEventService();

        // define search criteria
         EventCriteria criteria = new EventCriteria();
         criteria.setMaximumLatitude(45.0);
         criteria.setMinimumLatitude(44.8);
         criteria.setMaximumDepth(23.0);

         SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'hh:mm:ss");
         sdf.setTimeZone(TimeZone.getTimeZone("GMT"));
         Date startTime = sdf.parse("2009-11-08T08:00:00");
         Date endTime = sdf.parse("2011-11-08T09:00:00");

         criteria.setStartTime(startTime);
         criteria.setEndTime(endTime);
         criteria.includeAllMagnitudes(true);

         System.out.println(criteria.toUrlParams());

         // fetch the data
         List<Event> events = eventService.fetch(criteria);

         // process the results
         for (Event event : events) {
            System.out.println(event);
            System.out.println(event.getPreferredOrigin());
            // Events may have multiple magnitudes, so loop through them
            for (Magnitude magnitude : event.getMagnitudes()) {
               System.out.println("\t"+magnitude);
            }
            // Each event also may have a variety of origins.
            for (Origin origin : event.getOrigins()) {
               System.out.println("\t"+origin);
            }
         }
      } catch (FileNotFoundException e) {
         // No file found
         e.printStackTrace();
      } catch (IOException e) {
         // Something IO didn't work
         e.printStackTrace();
      } catch (NoDataFoundException e) {
         // The query didn't find any data
         e.printStackTrace();
      } catch (CriteriaException e) {
         // Something went wrong with the chosen criteria
         e.printStackTrace();
      } catch (ParseException e) {
         // Uparsable content
         e.printStackTrace();
      } catch (ServiceNotSupportedException e) {
		// Not a supported service
		e.printStackTrace();
	}
   }

}
