package edu.iris.dmc.ws.examples;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.TimeZone;

import edu.iris.dmc.criteria.CriteriaException;
import edu.iris.dmc.criteria.SacpzCriteria;
import edu.iris.dmc.sacpz.model.Sacpz;
import edu.iris.dmc.service.DataFormatException;
import edu.iris.dmc.service.NoDataFoundException;
import edu.iris.dmc.service.SacpzService;
import edu.iris.dmc.service.ServiceNotSupportedException;
import edu.iris.dmc.service.ServiceUtil;



public class SacpzExample {

	public static void main(String[] args) {

		ServiceUtil serviceManager;
		try {
			// initialize the service
			serviceManager = ServiceUtil.getInstance();

			serviceManager.setAppName("Examples");
			SacpzService sacpzService = serviceManager.getSacpzService();

			// define search criteria
			SacpzCriteria sacpzCriteria = new SacpzCriteria();
			sacpzCriteria.addNetwork("IU");
			sacpzCriteria.addStation("ANMO");
			sacpzCriteria.addChannel("BHZ");
			sacpzCriteria.addLocation("00");

			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'hh:mm:ss");
			sdf.setTimeZone(TimeZone.getTimeZone("GMT"));
			Date startTime = sdf.parse("2009-11-08T08:00:00");
			Date endTime = sdf.parse("2011-11-08T09:00:00");

			sacpzCriteria.setStartTime(startTime);
			sacpzCriteria.setEndTime(endTime);

			System.out.println(sacpzCriteria.toUrlParams());

			// fetch the data
			List<Sacpz> l = sacpzService.fetch(sacpzCriteria);

			// process the results
			for (Sacpz sacpz : l) {
				System.out.println(sacpz.getLatitude() + ""
						+ sacpz.getLongitude());
				
				//Do something with poles
				sacpz.getPoles();
			}
		} catch (FileNotFoundException e) {
			// No file found
			e.printStackTrace();
		} catch (IOException e) {
			// Something IO didn't work
			e.printStackTrace();
		} catch (NoDataFoundException e) {
			// The query didn't find any data
			e.printStackTrace();
		} catch (CriteriaException e) {
			// Something went wrong with the chosen criteria
			e.printStackTrace();
		} catch (ParseException e) {
			// Uparsable content
			e.printStackTrace();
		} catch (ServiceNotSupportedException e) {
			// Not a supported service
			e.printStackTrace();
		} catch (DataFormatException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

}
