package edu.iris.dmc.ws.tutorial;

//Import the error handling classes
import edu.iris.dmc.criteria.CriteriaException;   // error handling
import edu.iris.dmc.service.NoDataFoundException; // error handling
import edu.iris.dmc.service.ServiceNotSupportedException;


//ServiceUtil is where we obtain all the "hooks" to the web services.
import edu.iris.dmc.service.ServiceUtil;


//Import the classes specific to the EVENT example
import edu.iris.dmc.service.EventService;  // the "hook" to ws-event
import edu.iris.dmc.criteria.EventCriteria;// used to dictate which data to fetch
import edu.iris.dmc.event.model.Event;     // fetch returns an Event List
import edu.iris.dmc.event.model.Magnitude; // the events may have Magnitudes

//Import other Java classes
import java.util.List;
import java.io.FileNotFoundException;
import java.io.IOException;

public class EventTutorial {

	public static void main(String[] args) throws FileNotFoundException, IOException, NoDataFoundException, CriteriaException, ServiceNotSupportedException {
		// initialize the services
		ServiceUtil serviceUtil = ServiceUtil.getInstance();
        serviceUtil.setAppName("Tutorials");
		EventService eventService = serviceUtil.getEventService();

		//specify the criteria
		// we aren't concerned with a date range in this example,
		// but we COULD have specified a range as seen in the previous examples
		EventCriteria criteria = new EventCriteria();
		criteria.setMaximumLatitude(45.0);
		criteria.setMinimumLatitude(44.8);
		criteria.setMinimumMagnitude(5.0);
		
		// fetch a list of Event objects        
		List<Event> events = eventService.fetch(criteria);
		
		// display the events along with preferred origin 
		// and any associated magnitude values
		for (Event e : events) {
			   System.out.println("Event: " + e.getType() + " " + e.getFlinnEngdahlRegionName());
			   System.out.println("\t"+e.getPreferredOrigin());
			   for(Magnitude magnitude:e.getMagnitudes()){
			      System.out.printf("\tMag: %3.1f %s\n",
			         magnitude.getValue(),
			         magnitude.getType());
			   }
			   
			}
	}

}
