package edu.iris.dmc.service;

import java.util.ResourceBundle;

/**
 * A utility class to acquire services
 * 
 * @author yazan
 * 
 */
public class ServiceUtil {

	private static ServiceUtil instance;
	private StationService stationService;
	private WaveformService waveformService;
	private EventService eventService;
	private SacpzService sacpzService;
	private RespService respService;

	private String appName;

	static {
		instance = new ServiceUtil();
	}

	private ServiceUtil() {

		ResourceBundle rb = ResourceBundle.getBundle("edu.iris.dmc.iris");
		String stationUrl = rb.getString("stationUrl");
		String eventUrl = rb.getString("eventUrl");
		String sacpzUrl = rb.getString("sacpzUrl");
		String respUrl = rb.getString("respUrl");
		String dataselectUrl = rb.getString("dataselectUrl");

		String version = rb.getString("version");
		String userAgent = rb.getString("useragent");

		stationService = new StationService(stationUrl, version,
				rb.getString("stationVersion"), userAgent);
		respService = new RespService(respUrl, version,
				rb.getString("respVersion"), userAgent);
		eventService = new EventService(eventUrl, version,
				rb.getString("eventVersion"), userAgent);
		sacpzService = new SacpzService(sacpzUrl, version,
				rb.getString("sacpzVersion"), userAgent);
		waveformService = new WaveformService(dataselectUrl, version,
				rb.getString("bulkdataselectVersion"), userAgent);
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getAppName() {
		return this.appName;
	}

	/**
	 * Convenient method to get a station service object
	 * 
	 * @return StationService
	 */
	public StationService getStationService() {
		if (this.appName != null && this.appName.length() > 0) {
			stationService.setAppName(this.appName);
		}
		return stationService;
	}
	
	/**
	 * Convenient method to get a resp service object
	 * 
	 * @return StationService
	 */
	public RespService getRespService() {
		if (this.appName != null && this.appName.length() > 0) {
			respService.setAppName(this.appName);
		}
		return respService;
	}

	/**
	 * Convenient method to get a station service object targeting the specified
	 * url
	 * 
	 * @return StationService
	 */
	public StationService getStationService(String url) {
		if (this.appName != null && this.appName.length() > 0) {
			stationService.setAppName(this.appName);
		}
		if (url != null) {			
			stationService.setBaseUrl(url);
		}
		return stationService;
	}
	
	/**
	 * Convenient method to get a station service object targeting the specified
	 * url
	 * 
	 * @return StationService
	 */
	public RespService getRespService(String url) {
		if (this.appName != null && this.appName.length() > 0) {
			respService.setAppName(this.appName);
		}

		if (url != null) {
			respService.setBaseUrl(url);
		}
		return respService;
	}

	/**
	 * Convenient method to get a event service object
	 * 
	 * @return EventService
	 */
	public EventService getEventService() {
		if (this.appName != null && this.appName.length() > 0) {
			eventService.setAppName(this.appName);
		}
		return eventService;
	}

	/**
	 * Convenient method to get a event service object targeting the specified
	 * url
	 * 
	 * @return EventService
	 */
	public EventService getEventService(String url) {
		if (this.appName != null && this.appName.length() > 0) {
			eventService.setAppName(this.appName);
		}
		if (url != null) {
			eventService.setBaseUrl(url);
		}
		return eventService;
	}
	
	/**
	 * Convenient method to get a sacpz service object
	 * 
	 * @return EventService
	 */
	public SacpzService getSacpzService() {
		if (this.appName != null && this.appName.length() > 0) {
			sacpzService.setAppName(this.appName);
		}
		return sacpzService;
	}

	/**
	 * Convenient method to get a sacpz service object targeting the specified
	 * url
	 * 
	 * @return EventService
	 */
	public SacpzService getSacpzService(String url) {
		if (this.appName != null && this.appName.length() > 0) {
			sacpzService.setAppName(this.appName);
		}
		if (url != null) {
			sacpzService.setBaseUrl(url);
		}
		return sacpzService;
	}
	

	/**
	 * Convenient method to get a waveform service object
	 * 
	 * @return WaveFormService
	 */
	public WaveformService getWaveformService() {
		if (this.appName != null && this.appName.length() > 0) {
			waveformService.setAppName(this.appName);
		}
		return waveformService;
	}

	/**
	 * Convenient method to get a waveform service object
	 * 
	 * @return WaveFormService
	 */
	public WaveformService getWaveformService(String username, String password) {
		if (this.appName != null && this.appName.length() > 0) {
			waveformService.setAppName(this.appName);
		}
		waveformService.setAuth(username, password);
		return waveformService;
	}

	/**
	 * Convenient method to get a waveform service object targeting the
	 * specified url
	 * 
	 * @return WaveFormService
	 */
	public WaveformService getWaveformService(String url) {
		if (this.appName != null && this.appName.length() > 0) {
			waveformService.setAppName(this.appName);
		}
		if (url != null) {
			waveformService.setBaseUrl(url);
		}
		return waveformService;
	}

	public static ServiceUtil getInstance() {
		return instance;
	}
}
